## Improvement Log

### Change Summary

- **Date**: {{date}}
- **Improvement Area**: {{improvementArea}}
- **User Goal**: {{userGoal}}

### Changes Made

#### Change #{{changeNumber}}

**Issue**: {{issueDescription}}
**Solution**: {{solutionDescription}}
**Rationale**: {{changeRationale}}

**Files Modified**:
{{#modifiedFiles}}

- {{.}}
  {{/modifiedFiles}}

**Before**:

```markdown
{{beforeContent}}
```

**After**:

```markdown
{{afterContent}}
```

**User Approval**: {{userApproval}}
**Impact**: {{expectedImpact}}

---

{{/improvementLog}}
